@@ -93,7 +93,7 @@ module EdgeSet = Set.Make(G.E)
  * dependencies, connect binary packages to source packages according to
  * "bin2src" and omit connections of binary packages to source packages for
  * binary packages that qualify as "available" *)
-let graph_helper ?(num_cores=1) available bin2src univ partitionofsrc sl =
+let graph_helper available bin2src univ partitionofsrc sl =
   let g = G.create () in
   let seen = Hashtbl.create (List.length sl) in
   let rec aux = function
@@ -108,71 +108,7 @@ let graph_helper ?(num_cores=1) available bin2src univ partitionofsrc sl =
             let srcpkgid = CudfAdd.pkgtoint univ srcpkg in
             (srcpkgid, partitions)
         in
-        let instsets = if num_cores > 1 then
-            (* On 32 bit architectures it can happen that the result returned
-             * by parmap is too big to fit into the OCaml constraints for
-             * maximum allocatable memory. Should this problem occur, we
-             * repeat the computation with smaller chunk sizes.
-             * Unfortunately, should the result be too big and the child
-             * process throws an Out_of_memory error, then all the parent
-             * process sees is the Failure exception that the marshalling
-             * module throws. Thus, the Failure we do catch might also be
-             * caused by other problems than an Out_of_memory exception.
-             * https://github.com/rdicosmo/parmap/issues/46
-             *)
-            let rec splitjob maxsplits todo =
-                    let parmap ~ncores ?(csize = 1) f l =
-                      if ncores <= 1 then List.map f l
-                      else
-                        (*
-                        let input = ref l in
-                        let demux () = match !input with
-                          | [] -> raise Parany.End_of_input
-                          | x :: xs -> (input := xs; x) in
-                        let output = ref [] in
-                        let mux x =
-                          output := x :: !output in
-                           *)
-                        let inarray = Array.of_list l in
-                        let outarray = Array.make (List.length l) (0,[]) in
-                        let counter = ref 0 in
-                        let demux () =
-                          if !counter = List.length l then
-                            raise Parany.End_of_input
-                          else
-                            let res = (!counter, inarray.(!counter)) in
-                            incr counter;
-                            res
-                        in
-                        let mux (i,x) = outarray.(i) <- x in
-                        let fwrapper (i,x) = (i,f x) in
-                        (* for safety *)
-                        Parany.set_copy_on_work ();
-                        Parany.set_copy_on_mux ();
-                        (* parallel work *)
-                        Parany.run ~verbose:false ~csize ~nprocs:ncores ~demux ~work:fwrapper ~mux;
-                        (*!output*)
-                        Array.to_list outarray
-                    in parmap ~ncores:num_cores worker todo
-(*
-              try
-                Parmap.parmap ~ncores:num_cores worker (Parmap.L todo)
-              with
-              | Failure "input_value_from_block: bad object" |Out_of_memory -> begin
-                  if maxsplits <= 0 then fatal "exceeded maximum split depth";
-                  warning "parmap raised out of memory exception with list length %d, splitting job..." (List.length todo);
-                  let l1, l2 = List.split_nth ((List.length todo)/2) todo in
-                  let res1 = splitjob (maxsplits-1) l1 in
-                  let res2 = splitjob (maxsplits-1) l2 in
-                  List.append res1 res2
-                end
-    *)
-            in
-            let maxsplits = 4 in
-            splitjob maxsplits todo
-          else
-            List.map worker todo
-        in
+        let instsets = List.map worker todo in
         (* we must not do this iteration in the block above because side
          * effects from parallel blocks are discarded *)
         List.iter (fun (srcpkgid,_) -> Hashtbl.add seen srcpkgid ()) instsets;
@@ -243,7 +179,7 @@ let get_src_package ?(allowmismatch=false) univ pkg = try
 ;;
 
 (* create and time a normal buildgraph by calculating installation sets *)
-let dist_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) ?(opt=false) ?(num_cores=1) custom_is_ht univ sl =
+let dist_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) ?(opt=false) custom_is_ht univ sl =
   Util.Timer.start timer_build_graph;
   Util.Progress.set_total progressbar_build_graph (List.length sl);
 
@@ -263,11 +199,11 @@ let dist_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmism
       BootstrapCommon.compute_dependency_sets ~global_constraints ~partition:true custom_is_ht pool univ
   in
 
-  Util.Timer.stop timer_build_graph (graph_helper ~num_cores available bin2src univ partitionofsrc sl)
+  Util.Timer.stop timer_build_graph (graph_helper available bin2src univ partitionofsrc sl)
 ;;
 
 (* create and time a buildgraph by calculating installation closures *)
-let closure_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) ?(num_cores=1) univ sl =
+let closure_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) univ sl =
   Util.Timer.start timer_build_graph;
   Util.Progress.set_total progressbar_build_graph (List.length sl);
   let global_constraints =
@@ -294,11 +230,11 @@ let closure_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowm
     IntSet.empty, l
   in
 
-  Util.Timer.stop timer_build_graph (graph_helper ~num_cores available bin2src univ partitionofsrc sl)
+  Util.Timer.stop timer_build_graph (graph_helper available bin2src univ partitionofsrc sl)
 ;;
 
 (* create and time a normal buildgraph by calculating strong dependencies *)
-let strong_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) ?(num_cores=1) univ sl =
+let strong_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmismatch=false) univ sl =
   Util.Timer.start timer_build_graph;
   Util.Progress.set_total progressbar_build_graph (List.length sl);
   let global_constraints =
@@ -362,7 +298,7 @@ let strong_graph ?(global_constraints=[]) ?(available=(fun _ -> true)) ?(allowmi
     end
   in
 
-  Util.Timer.stop timer_build_graph (graph_helper ~num_cores available bin2src univ partitionofsrc sl)
+  Util.Timer.stop timer_build_graph (graph_helper available bin2src univ partitionofsrc sl)
 ;;
 
 (* Build the dependency source graph bfs from a root node *)
