@@ -12,7 +12,7 @@
 (**************************************************************************)
 
 open ExtLib
-open Common
+open Dose_common
 
 module IntSet = BootstrapCommon.IntSet
 module StringSet = BootstrapCommon.StringSet
