@@ -12,13 +12,13 @@
 (**************************************************************************************)
 
 open! ExtLib
-open Debian
-open Common
-open Algo
-open DoseparseNoRpm
+open Dose_debian
+open Dose_common
+open Dose_algo
+open Dose_doseparse
 
-module Src = Debian.Sources
-module Deb = Debian.Packages
+module Src = Sources
+module Deb = Packages
 
 module Options = struct
   open OptParse
@@ -95,18 +95,18 @@ let main () =
   (* we set the Debian.Debcudf options wrt the user provided options *)
   let options = Options.set_deb_options () in
   (* buildarch and native arch must be set to some architecture at this point *)
-  let buildarch = Option.get options.Debian.Debcudf.native in
+  let buildarch = Option.get options.Debcudf.native in
   (* hostarch can be None *)
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let noindep = options.Debian.Debcudf.drop_bd_indep in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let noindep = options.Debcudf.drop_bd_indep in
   let dropalternatives = OptParse.Opt.get Options.dropalternatives in
-  let profiles = options.Debian.Debcudf.profiles in
+  let profiles = options.Debcudf.profiles in
 
   let filter_external_sources par =
     if (OptParse.Opt.get Options.includextra) then true
     else
-      try not(Pef.Packages.parse_bool
-        ("extra-source-only",(Pef.Packages.assoc "extra-source-only" par)))
+      try not(Dose_pef.Packages.parse_bool
+        ("extra-source-only",(Dose_pef.Packages.assoc "extra-source-only" par)))
       with Not_found -> true
   in
 
@@ -142,9 +142,9 @@ let main () =
         end
   in
   let tables = Debcudf.init_tables (srclist @ pkglist) in
-  let global_constraints = Debian.Debcudf.get_essential ~options tables in
-  let to_cudf (p,v) = (p,Debian.Debcudf.get_cudf_version tables (p,v)) in
-  let from_cudf (p,v) = Debian.Debcudf.get_real_version tables (p,v) in
+  let global_constraints = Debcudf.get_essential ~options tables in
+  let to_cudf (p,v) = (p,Debcudf.get_cudf_version tables (p,v)) in
+  let from_cudf (p,v) = Debcudf.get_real_version tables (p,v) in
   let pp = CudfAdd.pp ?fields:None ?decode:None from_cudf in 
 
   (* XXX here latest could be a bit faster if done at the same time of the cudf
@@ -184,7 +184,7 @@ let main () =
     if OptParse.Opt.is_set Options.checkonly then begin
       List.flatten (
         List.map (fun ((n,a),c) ->
-          let (name,filter) = Pef.Pefcudf.pefvpkg to_cudf (("src:"^n,a),c) in
+          let (name,filter) = Dose_pef.Pefcudf.pefvpkg to_cudf (("src:"^n,a),c) in
           Cudf.lookup_packages ~filter !universe name
         ) (OptParse.Opt.get Options.checkonly)
       )
