@@ -12,10 +12,10 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open Algo
-open DoseparseNoRpm
+open Dose_common
+open Dose_debian
+open Dose_algo
+open Dose_doseparse
 
 #define __label __FILE__
 let label =  __label ;;
@@ -299,20 +299,20 @@ let main () =
   Util.Warning.disable "Sources";
 
   let options = Options.set_deb_options () in
-  let buildarch = Option.get options.Debian.Debcudf.native in
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let foreignarchs = options.Debian.Debcudf.foreign in
+  let buildarch = Option.get options.Debcudf.native in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let foreignarchs = options.Debcudf.foreign in
   let reqsrcarchall = OptParse.Opt.get Options.reqsrcarchall in
   let addsrcarchall = OptParse.Opt.get Options.addsrcarchall in
-  let noindep = options.Debian.Debcudf.drop_bd_indep in
+  let noindep = options.Debcudf.drop_bd_indep in
   let allowmismatch = OptParse.Opt.get Options.allowsrcmismatch in
 
   let binlist, (fgsrclist,bgsrclist), _ = BootstrapCommon.parse_packages ~noindep Options.parse_cmdline buildarch hostarch foreignarchs posargs in
   let srclist = fgsrclist @ bgsrclist in
-  let tables = Debian.Debcudf.init_tables ~options (srclist@binlist) in
-  let global_constraints = Debian.Debcudf.get_essential ~options tables in
-  let sl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) srclist in
-  let bl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) binlist in
+  let tables = Debcudf.init_tables ~options (srclist@binlist) in
+  let global_constraints = Debcudf.get_essential ~options tables in
+  let sl = List.map (Debcudf.tocudf ?inst:None ~options tables) srclist in
+  let bl = List.map (Debcudf.tocudf ?inst:None ~options tables) binlist in
 
   (* save mappings from cudf packages to binary packages *)
   let cudftobin_table = Hashtbl.create 30000 in
