@@ -48,7 +48,6 @@ module Options = struct
   let strongtype = StdOpt.store_true ()
   let closuretype = StdOpt.store_true ()
   let optgraph = StdOpt.store_true ()
-  let num_cores = StdOpt.int_option ~default:1 ()
 
   open OptParser ;;
 
@@ -65,7 +64,6 @@ module Options = struct
   add options ~group:prog_group ~long_name:"strongtype" ~help:"generate a strong build graph (only strong dependencies)" strongtype;
   add options ~group:prog_group ~long_name:"closuretype" ~help:"generate a dependency closure build graph (all dependency relationships)" closuretype;
   add options ~group:prog_group ~long_name:"optgraph" ~help:"generate installation sets with a minimum number of unavailable binary packages" optgraph;
-  add options ~group:prog_group ~short_name:'j' ~long_name:"jobs" ~help:"How many worker processes to run in parallel. Default: 1" num_cores;
 
   include StdOptions.InputOptions;;
   let default = List.filter (fun e -> not (List.mem e ["compare"; "checkonly"; "latest";"outfile";"inputtype"])) StdOptions.InputOptions.default_options in
@@ -94,7 +92,6 @@ let main () =
   let strongtype = OptParse.Opt.get Options.strongtype in
   let closuretype = OptParse.Opt.get Options.closuretype in
   let optgraph = OptParse.Opt.get Options.optgraph in
-  let num_cores = OptParse.Opt.get Options.num_cores in
 
   if strongtype && closuretype then
     fatal "cannot have --strongtype and --closuretype at the same time";
@@ -134,12 +131,12 @@ let main () =
 
   let bg =
     if strongtype then begin
-      BuildGraph.strong_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch ~num_cores universe fgsl
+      BuildGraph.strong_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch universe fgsl
     end else if closuretype then begin
-      BuildGraph.closure_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch ~num_cores universe fgsl
+      BuildGraph.closure_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch universe fgsl
     end else begin
       (* create a buildgraph and a sourcegraph *)
-      BuildGraph.dist_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch ~opt:optgraph ~num_cores custom_is_ht universe fgsl
+      BuildGraph.dist_graph ~global_constraints ~available ~allowmismatch:allowsrcmismatch ~opt:optgraph custom_is_ht universe fgsl
     end
   in
 
