@@ -13,13 +13,13 @@ tools = {
             "botch-latest-version",
             "botch-bin2src",
             "botch-src2bin",
-            "botch-build-closure",
             "botch-clean-repository",
             "botch-add-arch",
             "botch-convert-arch",
             "botch-remove-virtual-disjunctions",
             "botch-optuniv",
             "botch-fix-cross-problems",
+            "botch-filter-src-builds-for",
             ],
         "analysis of Packages and Sources control files": [
             "botch-packages-diff",
@@ -36,10 +36,18 @@ tools = {
             "botch-graphml2dot",
             "botch-collapse-srcgraph",
             "botch-profile-build-fvs",
+            "botch-buildgraph2packages",
+            "botch-graph-tred",
+            "botch-graph2text",
             ],
         "extract regions from graphs": [
-            "botch-extract-neighborhood",
+            "botch-graph-neighborhood",
             "botch-extract-scc",
+            "botch-graph-ancestors",
+            "botch-graph-descendants",
+            "botch-graph-shortest-path",
+            "botch-graph-sinks",
+            "botch-graph-sources",
             ],
         "dose3 wrappers": [
             "botch-dose2html",
@@ -73,6 +81,8 @@ tools = {
             "botch-cross",
             "botch-native",
             "botch-transition",
+            "botch-y-u-no-bootstrap",
+            "botch-y-u-b-d-transitive-essential",
             ]
         }
 
