@@ -12,10 +12,10 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open Algo
-open DoseparseNoRpm
+open Dose_common
+open Dose_debian
+open Dose_algo
+open Dose_doseparse
 
 #define __label __FILE__
 let label =  __label ;;
@@ -63,18 +63,18 @@ let main () =
   StdDebug.all_quiet (OptParse.Opt.get Options.quiet);
 
   let options = Options.set_deb_options () in
-  let buildarch = Option.get options.Debian.Debcudf.native in
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let foreignarchs = options.Debian.Debcudf.foreign in
+  let buildarch = Option.get options.Debcudf.native in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let foreignarchs = options.Debcudf.foreign in
   let addarchall = OptParse.Opt.get Options.addarchall in
-  let noindep = options.Debian.Debcudf.drop_bd_indep in
+  let noindep = options.Debcudf.drop_bd_indep in
   let allowsrcmismatch = OptParse.Opt.get Options.allowsrcmismatch in
 
   let binlist, (fgsrclist, bgsrclist), _ = BootstrapCommon.parse_packages ~noindep Options.parse_cmdline buildarch hostarch foreignarchs posargs in
-  let tables = Debian.Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
-  let fgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
-  let bgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
-  let bl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) binlist in
+  let tables = Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
+  let fgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
+  let bgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
+  let bl = List.map (Debcudf.tocudf ?inst:None ~options tables) binlist in
 
   (* create a hashtable mapping cudf package name,version,arch tuples to
    * Packages.package format822 stanzas *)
@@ -132,7 +132,7 @@ let main () =
                        Cudf.install = to_install } in
   let criteria = "-sum(solution,issource)" in
   let cmd = "aspcud $in $out $pref" in
-  let dummy = { Algo.Depsolver.dummy_request with
+  let dummy = { Depsolver.dummy_request with
                 Cudf.depends =
                   List.map (fun (_,pkglist) ->
                       List.map (fun pkg ->
@@ -150,9 +150,9 @@ let main () =
       stdout
   in
   begin match r with
-    |Algo.Depsolver.Error s -> fatal "%s" s
-    |Algo.Depsolver.Unsat _ -> fatal "(UNSAT) No Solutions according to the given preferences"
-    |Algo.Depsolver.Sat (_,soluniv) ->
+    |Depsolver.Error s -> fatal "%s" s
+    |Depsolver.Unsat _ -> fatal "(UNSAT) No Solutions according to the given preferences"
+    |Depsolver.Sat (_,soluniv) ->
       (* print out all selected binary packages *)
       Cudf.iter_packages (fun pkg ->
           let is_src = try (Cudf.lookup_package_property pkg "type") = "src"
