@@ -12,10 +12,10 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
 open Datatypes_t
-open DoseparseNoRpm
+open Dose_common
+open Dose_debian
+open Dose_doseparse
 
 #define __label __FILE__
 let label =  __label ;;
@@ -83,10 +83,10 @@ let main () =
   let reduced_deps_files = OptParse.Opt.get Options.remove_reduced in
   let allowsrcmismatch = OptParse.Opt.get Options.allowsrcmismatch in
   let options = Options.set_deb_options () in
-  let noindep = options.Debian.Debcudf.drop_bd_indep in
-  let buildarch = Option.get options.Debian.Debcudf.native in
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let foreignarchs = options.Debian.Debcudf.foreign in
+  let noindep = options.Debcudf.drop_bd_indep in
+  let buildarch = Option.get options.Debcudf.native in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let foreignarchs = options.Debcudf.foreign in
 
   let bgf, sgf, posargs = match posargs with
    | bgf::sgf::l -> bgf,sgf,l
@@ -95,10 +95,10 @@ let main () =
 
   let (binlist, (fgsrclist,bgsrclist), _) = BootstrapCommon.parse_packages ~noindep Options.parse_cmdline buildarch hostarch foreignarchs posargs in
 
-  let tables = Debian.Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
-  let fgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
-  let bgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
-  let pkglist = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) binlist in
+  let tables = Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
+  let fgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
+  let bgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
+  let pkglist = List.map (Debcudf.tocudf ?inst:None ~options tables) binlist in
   let universe = Cudf.load_universe (BootstrapCommon.unique [pkglist;fgsl;bgsl]) in
 
   let module BG = BuildGraph.G in
