@@ -2,7 +2,8 @@
 
 from __future__ import print_function
 import sys
-sys.path.append('/usr/share/botch')
+
+sys.path.append("/usr/share/botch")
 from util import read_reduced_deps, read_weak_deps, read_fas
 
 
@@ -25,22 +26,30 @@ def checkfas(weak, droppable, fas, verbose=False):
     return result
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import argparse
+
     parser = argparse.ArgumentParser(
-        description=("given any number of droppable dependencies and a " +
-                     "feedback arc set, show which edges in the feedback " +
-                     "arc set are not droppable"))
-    parser.add_argument('--remove-weak', type=read_weak_deps,
-                        help="A filename containing a list of weak build " +
-                             "dependencies")
-    parser.add_argument('--remove-reduced', type=read_reduced_deps,
-                        help="One or more filename containing a list of " +
-                             "droppable build dependencies, separated by " +
-                             "commas.")
-    parser.add_argument('fas', type=read_fas, help='A feedback arc set')
+        description=(
+            "given any number of droppable dependencies and a "
+            + "feedback arc set, show which edges in the feedback "
+            + "arc set are not droppable"
+        )
+    )
     parser.add_argument(
-        '-v', '--verbose', action='store_true', help='be verbose')
+        "--remove-weak",
+        type=read_weak_deps,
+        help="A filename containing a list of weak build " + "dependencies",
+    )
+    parser.add_argument(
+        "--remove-reduced",
+        type=read_reduced_deps,
+        help="One or more filename containing a list of "
+        + "droppable build dependencies, separated by "
+        + "commas.",
+    )
+    parser.add_argument("fas", type=read_fas, help="A feedback arc set")
+    parser.add_argument("-v", "--verbose", action="store_true", help="be verbose")
     args = parser.parse_args()
     result = checkfas(args.remove_weak, args.droppable, args.fas, args.verbose)
     for r in result:
