@@ -2,7 +2,8 @@
 
 from __future__ import print_function
 import sys
-sys.path.append('/usr/share/botch')
+
+sys.path.append("/usr/share/botch")
 from util import get_fh_out, read_tag_file
 
 
@@ -11,9 +12,9 @@ def convert_arch(fromarch, toarch, inPackages, outPackages, verbose=False):
     nr_all = 0
     for pkg in inPackages:
         nr_all += 1
-        arch = pkg['Architecture']
+        arch = pkg["Architecture"]
         if arch == fromarch:
-            pkg['Architecture'] = toarch
+            pkg["Architecture"] = toarch
             nr_modified += 1
 
     with outPackages as outfile:
@@ -22,26 +23,26 @@ def convert_arch(fromarch, toarch, inPackages, outPackages, verbose=False):
             outfile.write(b"\n")
 
     if verbose:
-        print("modified %d out of %d packages" %
-              (nr_modified, nr_all), file=sys.stderr)
+        print("modified %d out of %d packages" % (nr_modified, nr_all), file=sys.stderr)
 
     return True
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import argparse
+
     parser = argparse.ArgumentParser(
-        description=("convert architecture of a Packages file from fromarch " +
-                     "to toarch"))
+        description=(
+            "convert architecture of a Packages file from fromarch " + "to toarch"
+        )
+    )
     parser.add_argument("fromarch", help="architecture to convert from")
     parser.add_argument("toarch", help="architecture to convert to")
-    parser.add_argument(
-        "inPackages", type=read_tag_file, help="input Packages file")
-    parser.add_argument(
-        "outPackages", type=get_fh_out, help="output Packages file")
-    parser.add_argument(
-        '-v', '--verbose', action='store_true', help='be verbose')
+    parser.add_argument("inPackages", type=read_tag_file, help="input Packages file")
+    parser.add_argument("outPackages", type=get_fh_out, help="output Packages file")
+    parser.add_argument("-v", "--verbose", action="store_true", help="be verbose")
     args = parser.parse_args()
-    ret = convert_arch(args.fromarch, args.toarch,
-                       args.inPackages, args.outPackages, args.verbose)
+    ret = convert_arch(
+        args.fromarch, args.toarch, args.inPackages, args.outPackages, args.verbose
+    )
     exit(not ret)
