@@ -7,7 +7,6 @@ PROGNAME=`basename $0`
 CUSTOMTMP="no"
 OUTDIR="./"
 KEEP="no"
-NUM_CORES="1"
 DEVELOP="no"
 TIMERS=
 ALLOWSRCMISMATCH=
@@ -34,8 +33,6 @@ usage() {
 	echo "                        package of a different version than themselves" >&2
 	echo " -e, --ignoresrclessbin Ignore binary packages without a source package" >&2
 	echo " -b, --sapsb            Calculate strong articulation points and bridges" >&2
-	echo " -j, --jobs=NUM   Number of threads or processes to run in parallel" >&2
-	echo "                  where applicable" >&2
 	echo " -I, --deb-drop-b-d-indep Drop Build-Depends-Indep dependencies" >&2
 	echo " -v, --verbose    Be more verbose" >&2
 	echo " -d, --debug      Maximum verbosity" >&2
@@ -67,7 +64,7 @@ trap "die \"got signal\"" 1 2 15
 getopt -T > /dev/null && exitcode=0 || exitcode=$?
 if [ $exitcode -eq 4 ]; then
 	# GNU enhanced getopt is available
-	ARGS=`getopt --long help,output:,tmp:,optgraph,timers,allowsrcmismatch,ignoresrclessbin,sapsb,online,jobs:,deb-drop-b-d-indep,verbose,debug,develop --options ho:t:GTmebwj:IvdD -- "$@"`
+	ARGS=`getopt --long help,output:,tmp:,optgraph,timers,allowsrcmismatch,ignoresrclessbin,sapsb,online,deb-drop-b-d-indep,verbose,debug,develop --options ho:t:GTmebwj:IvdD -- "$@"`
 else
 	# Original getopt is available
 	ARGS=`getopt ho:t:GTmebwj:IvdD "$@"`
@@ -91,7 +88,6 @@ while [ $# -gt 0 ]; do
 		-m | --allowsrcmismatch) ALLOWSRCMISMATCH=--allowsrcmismatch;;
 		-e | --ignoresrclessbin) IGNORESRCLESSBIN=--ignoresrclessbin;;
 		-b | --sapsb)    SAPSB=--sapsb;;
-		-j | --jobs)    NUM_CORES="$2"; shift;;
 		-I | --deb-drop-b-d-indep) DROPBDINDEP=--deb-drop-b-d-indep;;
 		-v | --verbose) VERBOSE=--verbose;;
 		-d | --debug)   set -x;;
@@ -272,7 +268,7 @@ echo " + creating a self-contained repository graph..." >&2
 # $tmp/minimal-$HOSTARCH
 # the graph is started from all source packages that have been crossed before
 # and are thus creating the binary packages in $tmp/minimal-$HOSTARCH
-run $bin_create_graph $VERBOSE $DROPBDINDEP --jobs=$NUM_CORES \
+run $bin_create_graph $VERBOSE $DROPBDINDEP \
 	--deb-ignore-essential --progress --timers \
 	-A "$tmp/available-all" $ALLOWSRCMISMATCH --deb-native-arch=$HOSTARCH \
 	--bg $sources $hostpackages $tmp/crossed-src \
@@ -426,7 +422,7 @@ UNIVERSE="--deb-native-arch=$BUILDARCH --deb-host-arch=$HOSTARCH --bg $sources $
 # was made sure to contain a coinstallation set of essential earlier in this
 # script
 run $bin_create_graph $VERBOSE $DROPBDINDEP $OPTGRAPH --progress --timers \
-	--jobs=$NUM_CORES --deb-ignore-essential \
+	--deb-ignore-essential \
 	-A "$tmp/available" $ALLOWSRCMISMATCH $UNIVERSE \
 	> "${OUTDIR}/buildgraph.xml" || die "create graph failed"
 
