@@ -340,15 +340,15 @@ def print_footer(outfile, timestamp, srcs=[], srcsdir="", wwwroot=""):
         for src in sorted([s for s in srcs if s is not None]):
             print('<a href="%s%s.html">%s</a>' % (srcsdir, src, src), file=outfile)
 
-    url = "https://gitlab.mister-muffin.de/debian-bootstrap/bootstrap_debian_net"
+    url = "https://salsa.debian.org/debian-bootstrap-team/boott"
     footer = """
     <hr />
     <p>The JSON data used to generate these pages was computed using botch, the
     bootstrap/build ordering tool chain. The source code of botch can be
     redistributed under the terms of the LGPL3+ with an OCaml linking
     exception. The source code can be retrieved from <a
-    href="https://gitlab.mister-muffin.de/debian-bootstrap/botch">
-    https://gitlab.mister-muffin.de/debian-bootstrap/botch</a></p>
+    href="https://salsa.debian.org/debian-bootstrap-team/botch">
+    https://salsa.debian.org/debian-bootstrap-team/botch</a></p>
 
     <p>The html pages were generated by code which can be retrieved from <a
     href="%s"> %s</a> and which can be redistributed under the terms of the
@@ -663,7 +663,7 @@ if __name__ == "__main__":
         for b in res.decode().split("\n\n"):
             if not b:
                 continue
-            d = {k: v for k, v in [l.split("\t") for l in b.split("\n") if l.strip()]}
+            d = {k: v for k, v in [L.split("\t") for L in b.split("\n") if L.strip()]}
             binpkgbugs[d["package"]].append(d["bug_num"])
             for s in d["source"].split(","):
                 s = s.strip()
