@@ -19,8 +19,8 @@ def sob(binpkg):
 
 
 # string of list
-def sobl(l):
-    return " ".join([sob(pkg) for pkg in l])
+def sobl(L):
+    return " ".join([sob(pkg) for pkg in L])
 
 
 if __name__ == "__main__":
