@@ -8,7 +8,8 @@
 # output is sorted by name, then by version, then by architecture
 
 import sys
-sys.path.append('/usr/share/botch')
+
+sys.path.append("/usr/share/botch")
 from util import get_fh_out, sort_pkgs_key, read_tag_file
 
 
@@ -17,7 +18,7 @@ def packages_union(inPackages, outPackages, verbose=False):
 
     for packages in inPackages:
         for pkg in packages:
-            result[(pkg['Package'], pkg['Architecture'], pkg['Version'])] = pkg
+            result[(pkg["Package"], pkg["Architecture"], pkg["Version"])] = pkg
 
     with outPackages as outfile:
         for pkg in sorted(list(result.keys()), key=sort_pkgs_key):
@@ -27,15 +28,15 @@ def packages_union(inPackages, outPackages, verbose=False):
     return True
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import argparse
-    parser = argparse.ArgumentParser(
-        description=("merge one or more Packages files"))
-    parser.add_argument('inPackages', type=read_tag_file, nargs='+',
-                        help="input Packages files")
+
+    parser = argparse.ArgumentParser(description=("merge one or more Packages files"))
     parser.add_argument(
-        'outPackages', type=get_fh_out, help='output Packages file')
-    parser.add_argument('--verbose', action='store_true', help='be verbose')
+        "inPackages", type=read_tag_file, nargs="+", help="input Packages files"
+    )
+    parser.add_argument("outPackages", type=get_fh_out, help="output Packages file")
+    parser.add_argument("--verbose", action="store_true", help="be verbose")
     args = parser.parse_args()
     ret = packages_union(args.inPackages, args.outPackages, args.verbose)
     exit(not ret)
