@@ -27,14 +27,10 @@ def sob(binpkg):
 
 def sos(srcpkg):
     name, ver = srcpkg
-    return (
-        '<a href="/source/%s_%s.html" class="pkg"'
-        % (
-            name,
-            ver,
-        )
-        + ' title="src:%s&nbsp;(=&nbsp;%s)">src:%s</a>' % (name, ver, name)
-    )
+    return '<a href="/source/%s_%s.html" class="pkg"' % (
+        name,
+        ver,
+    ) + ' title="src:%s&nbsp;(=&nbsp;%s)">src:%s</a>' % (name, ver, name)
 
 
 # string of list
@@ -52,14 +48,10 @@ def sov(vertex):
     if t == "SrcPkg":
         name, ver = data
         fullname = "src:%s&nbsp;(=&nbsp;%s)" % (name, ver)
-        return (
-            '<a href="/source/%s_%s.html" class="pkg"'
-            % (
-                name,
-                ver,
-            )
-            + ' title="%s">src:%s</a>' % (fullname, name)
-        )
+        return '<a href="/source/%s_%s.html" class="pkg"' % (
+            name,
+            ver,
+        ) + ' title="%s">src:%s</a>' % (fullname, name)
     elif t == "InstSet":
         (name, arch, ver), instset = data
         instset = ", ".join(
@@ -88,14 +80,14 @@ def soc(c):
         if t == "SrcPkg":
             # the previous edge was a "buildsfrom" edge
             res += (
-                u' <span title="builds from" class="arrowouter">'
-                + u'<span class="arrowinner">→</span></span> '
+                ' <span title="builds from" class="arrowouter">'
+                + '<span class="arrowinner">→</span></span> '
             )
         elif t == "InstSet":
             # the previous edge was a "builddepends" edge
             res += (
-                u' <span title="build depends" class="arrowouter">'
-                + u'<span class="arrowinner">⇢</span></span> '
+                ' <span title="build depends" class="arrowouter">'
+                + '<span class="arrowinner">⇢</span></span> '
             )
         else:
             raise Exception("invalid vertex type: %s" % t)
